# Server REST e autenticazione basata su JWT

&copy; 2024 &ndash; prof. Roberto Fuligni

## Caratteristiche del server

Il server gestisce risorse protette e non protette. 
Un metodo di accesso alla risorsa è protetto quando il metodo,
o la classe a cui appartiene, è associato ad almeno una delle
seguenti annotazioni: *@PermitAll*, *@DenyAll*, *@RolesAllowed*.

La richiesta di una risorsa protetta deve includere la seguente
riga d'intestazione contenente un token JWT:

```
Authorization: Bearer <token>
```

Il server di questo progetto supporta l'autenticazione basata su *chiave API*:  
per ottenere un token, il client una richiestaPOST all'url `/api/auth` specificando
il valore della chiave API. La risorsa *AuthResource*, dedicata a questo scopo,
accetta la seguente richiesta di autenticazione:

* Richiesta di tipo **application/x-www-form-urlencoded**: contiene nel body della richiesta il
   campo `apikey=abc123`

Il server elabora la richiesta generando e firmando un token valido per due ore
contenente l'id dell'utente e un elenco di ruoli associati. Il token è restituito al client
ed è utilizzato da quest'ultimo nelle successive
richieste di accesso alle risorse protette.

Il meccanismo di protezione delle risorse REST è costituito da due filtri distinti che 
vengono automaticamente attivati prima dell'elaborazione della risposta:

1. **Filtro di autenticazione** `JwtAuthenticationFilter`: nel caso di accesso a una risorsa protetta, 
questo filtro valida il token JWT presente nella richiesta. Se il token è corretto, genera un *SecurityContext* 
contenente l'id dell'utente e i ruoli di appartenenza estratti dal token.

2. **Filtro di autorizzazione** `JwtAuthorizationFilter`: concede o nega l'accesso alla risorsa protetta analizzando le
annotazioni associate e i ruoli presenti nel *SecurityContext*:
    * *@DenyAll*: nessun ruolo è autorizzato ad accedere alla risorsa;
    * *@RolesAllowed*: solo i ruoli specificati sono autorizzati;
    * *@PermitAll*: tutti i ruoli sono autorizzati (è richiesto comunque il completamento dell'autenticazione da parte del client)

## Test di funzionamento

Per ottenere un nuovo token JWT fornendo la chiave API `abc123`:

```
curl -v -H "Content-Type: application/x-www-form-urlencoded" ^
http://localhost:8080/server-colori-jwt/api/auth -d "apikey=abc123"
```

Per includere il token JWT in una richiesta di risorsa:

```
  curl -v -H "Authorization: Bearer <token>" ^
  http://localhost:8080/server-colori-jwt/api/colori
```