/*
 *            File: AuthResource.java
 *          Autore: Roberto FULIGNI
 * Ultima modifica: 17/04/2024
 *
 *     Descrizione: Autenticazione degli utenti di servizi REST basata su API key
 *                  e assegnazione di token JWT.
 */

package edu.fauser.netlab;

import edu.fauser.netlab.jwtserver.JwtUtility;

import javax.ws.rs.*;
import javax.ws.rs.core.Response;

@Path("/auth")
@Consumes("application/x-www-form-urlencoded")
@Produces("application/json")
public class AuthResource {
    // Autenticazione basata su API key dell'utente.
    // Il contenuto della richiesta POST, di tipo application/x-www-form-urlencoded,
    // deve includere il parametro apikey=<valore>
    //
    // curl -v -H "Content-Type: application/x-www-form-urlencoded" ^
    // http://localhost:8080/server-colori-jwt/api/auth -d "apikey=abc123"

    @POST
    public Response autenticaApiKey(@FormParam("apikey") String apiKey) {
        String idUtente = null;
        String[] ruoli = null;

        if (apiKey != null) {
            if (apiKey.compareToIgnoreCase("abc123") == 0) {
                idUtente = "1000";
                ruoli = new String[]{"gruppo1-rest"};
            } else if (apiKey.compareToIgnoreCase("def456") == 0) {
                idUtente = "2000";
                ruoli = new String[]{"gruppo2-rest"};
            }
        }
        if (idUtente == null)
            return Response.status(Response.Status.UNAUTHORIZED)
                    .entity("API key mancante o errata").build();

        String token = JwtUtility.generaToken(idUtente, ruoli);
        return Response.ok(token).build();
    }
}
