/*
 *            File: JwtSecurityContext.java
 *          Autore: Roberto FULIGNI
 * Ultima modifica: 17/04/2024
 *
 *     Descrizione: Definizione del Security Context per l'utente
 *                  proprietario del token JWT.
 */

package edu.fauser.netlab.jwtserver;

import javax.ws.rs.core.SecurityContext;
import java.security.Principal;
import java.util.List;

public class JwtSecurityContext implements SecurityContext {
    public class UserPrincipal implements Principal {
        String name;
        @Override
        public String getName() {
            return name;
        }

        public UserPrincipal(String name) {
            this.name = name;
        }
    }
    UserPrincipal user;
    List<String> roles;

    boolean isSecure;

    public JwtSecurityContext(String subject, List<String> roles, boolean isSecure) {
        this.user = new UserPrincipal(subject);
        this.roles = roles;
        this.isSecure = isSecure;
    }

    @Override
    public Principal getUserPrincipal() {
        return user;
    }

    @Override
    public boolean isUserInRole(String s) {
        for (var r : roles) {
            if (s.equals(r))
                return true;
        }
        return false;
    }

    @Override
    public boolean isSecure() {
        return this.isSecure;
    }

    @Override
    public String getAuthenticationScheme() {
        return "Bearer";
    }

}
