/*
 *            File: JwtUtility.java
 *          Autore: Roberto FULIGNI
 * Ultima modifica: 17/04/2024
 *
 *     Descrizione: Routine per la generazione e validazione
 *                  dei token JWT basate sulla libreria JJWT.
 *
 */

package edu.fauser.netlab.jwtserver;

import io.jsonwebtoken.*;

import java.util.Date;

public class JwtUtility {
    final static String ISSUER = "server-colori-jwt";
    final static String CHIAVE_SEGRETA = "aabbccddeeffgghhiijjkkllmmnnooppqqrrssttuuvvwwxxyyzz";
    final static long SCADENZA_MINUTI_TOKEN = 120;
    public static String generaToken(String idUtente, String[] ruoli) {
        Date oraCorrente = new Date();
        Date scadenza = new Date(oraCorrente.getTime() + SCADENZA_MINUTI_TOKEN * 60000);

        return Jwts.builder()
                .issuer(ISSUER)
                .subject(idUtente)
                .claim("roles", ruoli)
                .issuedAt(oraCorrente)
                .expiration(scadenza)
                .signWith(SignatureAlgorithm.HS256, CHIAVE_SEGRETA)
                .compact();
    }

    public static Claims validaToken(String token) throws JwtException {
        Jws<Claims> claims = Jwts.parser()
                .setSigningKey(CHIAVE_SEGRETA)
                .build()
                .parseSignedClaims(token);

        Claims payload = claims.getPayload();

        if (!payload.getIssuer().equals(ISSUER)) {
            throw new JwtException("Token non valido");
        }

        Date oraCorrente = new Date();
        if (payload.getExpiration().before(oraCorrente))
            throw new JwtException("Token scaduto");

        return payload;
    }
}
